@@ -1,7 +1,7 @@
 from __future__ import annotations
 from collections.abc import Callable, Generator
-from warnings import warn
 import contextlib
+
 import copy
 import json
 import os
@@ -35,9 +35,6 @@ from ocp_resources.constants import (
     TIMEOUT_1MINUTE,
     TIMEOUT_4MINUTES,
     TIMEOUT_10SEC,
-    TIMEOUT_30SEC,
-    TIMEOUT_5SEC,
-    TIMEOUT_1SEC,
 )
 from ocp_resources.event import Event
 from timeout_sampler import (
@@ -205,12 +202,6 @@ class ClassProperty:
         return self.func(owner)
 
 
-class ValueMismatch(Exception):
-    """
-    Raises when value doesn't match the class value
-    """
-
-
 class Resource:
     """
     Base class for API resources
@@ -222,141 +213,152 @@ class Resource:
     timeout_seconds: int = TIMEOUT_1MINUTE
 
     class Status:
-        SUCCEEDED = "Succeeded"
-        FAILED = "Failed"
-        DELETING = "Deleting"
-        DEPLOYED = "Deployed"
-        PENDING = "Pending"
-        COMPLETED = "Completed"
-        RUNNING = "Running"
-        READY = "Ready"
-        TERMINATING = "Terminating"
-        ERROR = "Error"
-        COMPLETE = "Complete"
+        SUCCEEDED: str = "Succeeded"
+        FAILED: str = "Failed"
+        DELETING: str = "Deleting"
+        DEPLOYED: str = "Deployed"
+        PENDING: str = "Pending"
+        COMPLETED: str = "Completed"
+        RUNNING: str = "Running"
+        READY: str = "Ready"
+        TERMINATING: str = "Terminating"
+        ERROR: str = "Error"
+        COMPLETE: str = "Complete"
 
     class Condition:
-        UPGRADEABLE = "Upgradeable"
-        AVAILABLE = "Available"
-        DEGRADED = "Degraded"
-        PROGRESSING = "Progressing"
-        CREATED = "Created"
-        RECONCILE_COMPLETE = "ReconcileComplete"
-        READY = "Ready"
-        FAILING = "Failing"
+        UPGRADEABLE: str = "Upgradeable"
+        AVAILABLE: str = "Available"
+        DEGRADED: str = "Degraded"
+        PROGRESSING: str = "Progressing"
+        CREATED: str = "Created"
+        RECONCILE_COMPLETE: str = "ReconcileComplete"
+        READY: str = "Ready"
+        FAILING: str = "Failing"
 
         class Status:
-            TRUE = "True"
-            FALSE = "False"
-            UNKNOWN = "Unknown"
+            TRUE: str = "True"
+            FALSE: str = "False"
+            UNKNOWN: str = "Unknown"
 
         class Phase:
-            INSTALL_READY = "InstallReady"
-            SUCCEEDED = "Succeeded"
+            INSTALL_READY: str = "InstallReady"
+            SUCCEEDED: str = "Succeeded"
 
         class Reason:
-            ALL_REQUIREMENTS_MET = "AllRequirementsMet"
-            INSTALL_SUCCEEDED = "InstallSucceeded"
+            ALL_REQUIREMENTS_MET: str = "AllRequirementsMet"
+            INSTALL_SUCCEEDED: str = "InstallSucceeded"
+            NETWORK_ATTACHMENT_DEFINITION_READY: str = "NetworkAttachmentDefinitionReady"
+            SYNC_ERROR: str = "SyncError"
+
+        class Type:
+            NETWORK_READY: str = "NetworkReady"
 
     class Interface:
         class State:
-            UP = "up"
-            DOWN = "down"
-            ABSENT = "absent"
+            UP: str = "up"
+            DOWN: str = "down"
+            ABSENT: str = "absent"
 
     class ApiGroup:
-        AAQ_KUBEVIRT_IO = "aaq.kubevirt.io"
-        ADMISSIONREGISTRATION_K8S_IO = "admissionregistration.k8s.io"
-        APIEXTENSIONS_K8S_IO = "apiextensions.k8s.io"
-        APIREGISTRATION_K8S_IO = "apiregistration.k8s.io"
-        APP_KUBERNETES_IO = "app.kubernetes.io"
-        APPS = "apps"
-        BATCH = "batch"
-        BITNAMI_COM = "bitnami.com"
-        CDI_KUBEVIRT_IO = "cdi.kubevirt.io"
-        CLONE_KUBEVIRT_IO = "clone.kubevirt.io"
-        CLUSTER_OPEN_CLUSTER_MANAGEMENT_IO = "cluster.open-cluster-management.io"
-        CONFIG_OPENSHIFT_IO = "config.openshift.io"
-        CONSOLE_OPENSHIFT_IO = "console.openshift.io"
-        COORDINATION_K8S_IO = "coordination.k8s.io"
-        CSIADDONS_OPENSHIFT_IO = "csiaddons.openshift.io"
-        DATA_IMPORT_CRON_TEMPLATE_KUBEVIRT_IO = "dataimportcrontemplate.kubevirt.io"
-        DISCOVERY_K8S_IO = "discovery.k8s.io"
-        EVENTS_K8S_IO = "events.k8s.io"
-        EXPORT_KUBEVIRT_IO = "export.kubevirt.io"
-        FENCE_AGENTS_REMEDIATION_MEDIK8S_IO = "fence-agents-remediation.medik8s.io"
-        FORKLIFT_KONVEYOR_IO = "forklift.konveyor.io"
-        INSTANCETYPE_KUBEVIRT_IO = "instancetype.kubevirt.io"
-        HCO_KUBEVIRT_IO = "hco.kubevirt.io"
-        HIVE_OPENSHIFT_IO = "hive.openshift.io"
-        HOSTPATHPROVISIONER_KUBEVIRT_IO = "hostpathprovisioner.kubevirt.io"
-        IMAGE_OPENSHIFT_IO = "image.openshift.io"
-        IMAGE_REGISTRY = "registry.redhat.io"
-        INTEGREATLY_ORG = "integreatly.org"
-        K8S_CNI_CNCF_IO = "k8s.cni.cncf.io"
-        K8S_V1_CNI_CNCF_IO = "k8s.v1.cni.cncf.io"
-        KUBERNETES_IO = "kubernetes.io"
-        KUBEVIRT_IO = "kubevirt.io"
-        KUBEVIRT_KUBEVIRT_IO = "kubevirt.kubevirt.io"
-        LITMUS_IO = "litmuschaos.io"
-        MACHINE_OPENSHIFT_IO = "machine.openshift.io"
-        MACHINECONFIGURATION_OPENSHIFT_IO = "machineconfiguration.openshift.io"
-        MAISTRA_IO = "maistra.io"
-        METALLB_IO = "metallb.io"
-        METRICS_K8S_IO = "metrics.k8s.io"
-        MIGRATIONS_KUBEVIRT_IO = "migrations.kubevirt.io"
-        MONITORING_COREOS_COM = "monitoring.coreos.com"
-        MTQ_KUBEVIRT_IO = "mtq.kubevirt.io"
-        NETWORKADDONSOPERATOR_NETWORK_KUBEVIRT_IO = "networkaddonsoperator.network.kubevirt.io"
-        NETWORKING_ISTIO_IO = "networking.istio.io"
-        NETWORKING_K8S_IO = "networking.k8s.io"
-        NODE_LABELLER_KUBEVIRT_IO = "node-labeller.kubevirt.io"
-        NMSTATE_IO = "nmstate.io"
-        NODEMAINTENANCE_KUBEVIRT_IO = "nodemaintenance.kubevirt.io"
-        OBSERVABILITY_OPEN_CLUSTER_MANAGEMENT_IO = "observability.open-cluster-management.io"
-        OCS_OPENSHIFT_IO = "ocs.openshift.io"
-        OPERATOR_OPEN_CLUSTER_MANAGEMENT_IO = "operator.open-cluster-management.io"
-        OPERATOR_OPENSHIFT_IO = "operator.openshift.io"
-        OPERATORS_COREOS_COM = "operators.coreos.com"
-        OPERATORS_OPENSHIFT_IO = "operators.openshift.io"
-        OS_TEMPLATE_KUBEVIRT_IO = "os.template.kubevirt.io"
-        PACKAGES_OPERATORS_COREOS_COM = "packages.operators.coreos.com"
-        PERFORMANCE_OPENSHIFT_IO = "performance.openshift.io"
-        POLICY = "policy"
-        POOL_KUBEVIRT_IO = "pool.kubevirt.io"
-        PROJECT_OPENSHIFT_IO = "project.openshift.io"
-        RBAC_AUTHORIZATION_K8S_IO = "rbac.authorization.k8s.io"
-        REMEDIATION_MEDIK8S_IO = "remediation.medik8s.io"
-        RIPSAW_CLOUDBULLDOZER_IO = "ripsaw.cloudbulldozer.io"
-        ROUTE_OPENSHIFT_IO = "route.openshift.io"
-        SCHEDULING_K8S_IO = "scheduling.k8s.io"
-        SECURITY_ISTIO_IO = "security.istio.io"
-        SECURITY_OPENSHIFT_IO = "security.openshift.io"
-        SELF_NODE_REMEDIATION_MEDIK8S_IO = "self-node-remediation.medik8s.io"
-        SERVING_KSERVE_IO = "serving.kserve.io"
-        SNAPSHOT_STORAGE_K8S_IO = "snapshot.storage.k8s.io"
-        SNAPSHOT_KUBEVIRT_IO = "snapshot.kubevirt.io"
-        SRIOVNETWORK_OPENSHIFT_IO = "sriovnetwork.openshift.io"
-        SSP_KUBEVIRT_IO = "ssp.kubevirt.io"
-        STORAGE_K8S_IO = "storage.k8s.io"
-        STORAGECLASS_KUBERNETES_IO = "storageclass.kubernetes.io"
-        STORAGECLASS_KUBEVIRT_IO = "storageclass.kubevirt.io"
-        SUBRESOURCES_KUBEVIRT_IO = "subresources.kubevirt.io"
-        TEKTONTASKS_KUBEVIRT_IO = "tektontasks.kubevirt.io"
-        TEKTON_DEV = "tekton.dev"
-        TEMPLATE_KUBEVIRT_IO = "template.kubevirt.io"
-        TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
-        TRUSTYAI_OPENDATAHUB_IO = "trustyai.opendatahub.io"
-        UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
-        USER_OPENSHIFT_IO = "user.openshift.io"
-        V2V_KUBEVIRT_IO = "v2v.kubevirt.io"
-        VELERO_IO = "velero.io"
-        VM_KUBEVIRT_IO = "vm.kubevirt.io"
+        AAQ_KUBEVIRT_IO: str = "aaq.kubevirt.io"
+        ADMISSIONREGISTRATION_K8S_IO: str = "admissionregistration.k8s.io"
+        APIEXTENSIONS_K8S_IO: str = "apiextensions.k8s.io"
+        APIREGISTRATION_K8S_IO: str = "apiregistration.k8s.io"
+        APP_KUBERNETES_IO: str = "app.kubernetes.io"
+        APPS: str = "apps"
+        BATCH: str = "batch"
+        BITNAMI_COM: str = "bitnami.com"
+        CACHING_INTERNAL_KNATIVE_DEV: str = "caching.internal.knative.dev"
+        CDI_KUBEVIRT_IO: str = "cdi.kubevirt.io"
+        CLONE_KUBEVIRT_IO: str = "clone.kubevirt.io"
+        CLUSTER_OPEN_CLUSTER_MANAGEMENT_IO: str = "cluster.open-cluster-management.io"
+        CONFIG_OPENSHIFT_IO: str = "config.openshift.io"
+        CONSOLE_OPENSHIFT_IO: str = "console.openshift.io"
+        COORDINATION_K8S_IO: str = "coordination.k8s.io"
+        CSIADDONS_OPENSHIFT_IO: str = "csiaddons.openshift.io"
+        DATA_IMPORT_CRON_TEMPLATE_KUBEVIRT_IO: str = "dataimportcrontemplate.kubevirt.io"
+        DATASCIENCECLUSTER_OPENDATAHUB_IO: str = "datasciencecluster.opendatahub.io"
+        DISCOVERY_K8S_IO: str = "discovery.k8s.io"
+        DSCINITIALIZATION_OPENDATAHUB_IO: str = "dscinitialization.opendatahub.io"
+        EVENTS_K8S_IO: str = "events.k8s.io"
+        EXPORT_KUBEVIRT_IO: str = "export.kubevirt.io"
+        FENCE_AGENTS_REMEDIATION_MEDIK8S_IO: str = "fence-agents-remediation.medik8s.io"
+        FORKLIFT_KONVEYOR_IO: str = "forklift.konveyor.io"
+        HCO_KUBEVIRT_IO: str = "hco.kubevirt.io"
+        HELM_MARIADB_MMONTES_IO: str = "helm.mariadb.mmontes.io"
+        HIVE_OPENSHIFT_IO: str = "hive.openshift.io"
+        HOSTPATHPROVISIONER_KUBEVIRT_IO: str = "hostpathprovisioner.kubevirt.io"
+        IMAGE_OPENSHIFT_IO: str = "image.openshift.io"
+        IMAGE_REGISTRY: str = "registry.redhat.io"
+        INSTANCETYPE_KUBEVIRT_IO: str = "instancetype.kubevirt.io"
+        INTEGREATLY_ORG: str = "integreatly.org"
+        K8S_CNI_CNCF_IO: str = "k8s.cni.cncf.io"
+        K8S_MARIADB_COM: str = "k8s.mariadb.com"
+        K8S_OVN_ORG: str = "k8s.ovn.org"
+        K8S_V1_CNI_CNCF_IO: str = "k8s.v1.cni.cncf.io"
+        KUBERNETES_IO: str = "kubernetes.io"
+        KUBEVIRT_IO: str = "kubevirt.io"
+        KUBEVIRT_KUBEVIRT_IO: str = "kubevirt.kubevirt.io"
+        LITMUS_IO: str = "litmuschaos.io"
+        MACHINE_OPENSHIFT_IO: str = "machine.openshift.io"
+        MACHINECONFIGURATION_OPENSHIFT_IO: str = "machineconfiguration.openshift.io"
+        MAISTRA_IO: str = "maistra.io"
+        METALLB_IO: str = "metallb.io"
+        METRICS_K8S_IO: str = "metrics.k8s.io"
+        MIGRATIONS_KUBEVIRT_IO: str = "migrations.kubevirt.io"
+        MONITORING_COREOS_COM: str = "monitoring.coreos.com"
+        MTQ_KUBEVIRT_IO: str = "mtq.kubevirt.io"
+        NETWORKADDONSOPERATOR_NETWORK_KUBEVIRT_IO: str = "networkaddonsoperator.network.kubevirt.io"
+        NETWORKING_ISTIO_IO: str = "networking.istio.io"
+        NETWORKING_K8S_IO: str = "networking.k8s.io"
+        NMSTATE_IO: str = "nmstate.io"
+        NODE_LABELLER_KUBEVIRT_IO: str = "node-labeller.kubevirt.io"
+        NODEMAINTENANCE_KUBEVIRT_IO: str = "nodemaintenance.kubevirt.io"
+        OBSERVABILITY_OPEN_CLUSTER_MANAGEMENT_IO: str = "observability.open-cluster-management.io"
+        OCS_OPENSHIFT_IO: str = "ocs.openshift.io"
+        OPERATOR_OPEN_CLUSTER_MANAGEMENT_IO: str = "operator.open-cluster-management.io"
+        OPERATOR_OPENSHIFT_IO: str = "operator.openshift.io"
+        OPERATORS_COREOS_COM: str = "operators.coreos.com"
+        OPERATORS_OPENSHIFT_IO: str = "operators.openshift.io"
+        OS_TEMPLATE_KUBEVIRT_IO: str = "os.template.kubevirt.io"
+        PACKAGES_OPERATORS_COREOS_COM: str = "packages.operators.coreos.com"
+        PERFORMANCE_OPENSHIFT_IO: str = "performance.openshift.io"
+        POLICY: str = "policy"
+        POOL_KUBEVIRT_IO: str = "pool.kubevirt.io"
+        PROJECT_OPENSHIFT_IO: str = "project.openshift.io"
+        RBAC_AUTHORIZATION_K8S_IO: str = "rbac.authorization.k8s.io"
+        REMEDIATION_MEDIK8S_IO: str = "remediation.medik8s.io"
+        RIPSAW_CLOUDBULLDOZER_IO: str = "ripsaw.cloudbulldozer.io"
+        ROUTE_OPENSHIFT_IO: str = "route.openshift.io"
+        SCHEDULING_K8S_IO: str = "scheduling.k8s.io"
+        SECURITY_ISTIO_IO: str = "security.istio.io"
+        SECURITY_OPENSHIFT_IO: str = "security.openshift.io"
+        SELF_NODE_REMEDIATION_MEDIK8S_IO: str = "self-node-remediation.medik8s.io"
+        SERVING_KSERVE_IO: str = "serving.kserve.io"
+        SNAPSHOT_KUBEVIRT_IO: str = "snapshot.kubevirt.io"
+        SNAPSHOT_STORAGE_K8S_IO: str = "snapshot.storage.k8s.io"
+        SRIOVNETWORK_OPENSHIFT_IO: str = "sriovnetwork.openshift.io"
+        SSP_KUBEVIRT_IO: str = "ssp.kubevirt.io"
+        STORAGE_K8S_IO: str = "storage.k8s.io"
+        STORAGECLASS_KUBERNETES_IO: str = "storageclass.kubernetes.io"
+        STORAGECLASS_KUBEVIRT_IO: str = "storageclass.kubevirt.io"
+        SUBRESOURCES_KUBEVIRT_IO: str = "subresources.kubevirt.io"
+        TEKTON_DEV: str = "tekton.dev"
+        TEKTONTASKS_KUBEVIRT_IO: str = "tektontasks.kubevirt.io"
+        TEMPLATE_KUBEVIRT_IO: str = "template.kubevirt.io"
+        TEMPLATE_OPENSHIFT_IO: str = "template.openshift.io"
+        TRUSTYAI_OPENDATAHUB_IO: str = "trustyai.opendatahub.io"
+        UPLOAD_CDI_KUBEVIRT_IO: str = "upload.cdi.kubevirt.io"
+        USER_OPENSHIFT_IO: str = "user.openshift.io"
+        V2V_KUBEVIRT_IO: str = "v2v.kubevirt.io"
+        VELERO_IO: str = "velero.io"
+        VM_KUBEVIRT_IO: str = "vm.kubevirt.io"
 
     class ApiVersion:
-        V1 = "v1"
-        V1BETA1 = "v1beta1"
-        V1ALPHA1 = "v1alpha1"
-        V1ALPHA3 = "v1alpha3"
+        V1: str = "v1"
+        V1BETA1: str = "v1beta1"
+        V1ALPHA1: str = "v1alpha1"
+        V1ALPHA3: str = "v1alpha3"
 
     def __init__(
         self,
@@ -392,7 +394,7 @@ class Resource:
             yaml_file (str): yaml file for the resource
             delete_timeout (int): timeout associated with delete action
             dry_run (bool): dry run
-            node_selector (str): node selector
+            node_selector (dict): node selector
             node_selector_labels (str): node selector labels
             config_file (str): Path to config file for connecting to remote cluster.
             context (str): Context name for connecting to remote cluster.
@@ -438,7 +440,7 @@ class Resource:
         self.namespace: str = ""
         self.resource_dict: Dict[str, Any] = {}  # Filled in case yaml_file is not None
         self.node_selector_spec = self._prepare_node_selector_spec()
-        self.res: Dict[str, Any] = {}
+        self.res: Dict[Any, Any] = {}
         self.yaml_file_contents: str = ""
         self.initial_resource_version: str = ""
         self.logger = self._set_logger()
@@ -464,22 +466,7 @@ class Resource:
         )
 
     def _prepare_node_selector_spec(self) -> Dict[str, str]:
-        if self.node_selector:
-            if isinstance(self.node_selector, dict):
-                return self.node_selector
-            else:
-                warn(
-                    "node_selector `str` will be deprecated in next release (4.17), pass `dict` instead",
-                    DeprecationWarning,
-                    stacklevel=2,
-                )
-                return {f"{self.ApiGroup.KUBERNETES_IO}/hostname": self.node_selector}
-
-        elif self.node_selector_labels:
-            return self.node_selector_labels
-
-        else:
-            return {}
+        return self.node_selector or self.node_selector_labels or {}
 
     @ClassProperty
     def kind(cls) -> Optional[str]:  # noqa: N805
@@ -571,13 +558,14 @@ class Resource:
         self.create(wait=wait)
         return self
 
-    def clean_up(self, wait: bool = True) -> bool:
+    def clean_up(self, wait: bool = True, timeout: Optional[int] = None) -> bool:
         """
         For debug, export SKIP_RESOURCE_TEARDOWN to skip resource teardown.
         Spaces are important in the export dict
 
         Args:
             wait (bool, optional): Wait for resource deletion. Defaults to True.
+            timeout (int, optional): Timeout in seconds to wait for resource to be deleted. Defaults to 240.
 
         Returns:
             bool: True if resource was deleted else False.
@@ -608,7 +596,7 @@ class Resource:
             )
             return False
 
-        return self.delete(wait=wait, timeout=self.delete_timeout)
+        return self.delete(wait=wait, timeout=timeout or self.delete_timeout)
 
     @classmethod
     def _prepare_resources(
@@ -704,7 +692,12 @@ class Resource:
             TimeoutExpiredError: If resource still exists.
         """
         self.logger.info(f"Wait until {self.kind} {self.name} is deleted")
-        return self.client_wait_deleted(timeout=timeout)
+        samples = TimeoutSampler(wait_timeout=timeout, sleep=1, func=lambda: self.exists)
+        for sample in samples:
+            if not sample:
+                return True
+
+        return False
 
     @property
     def exists(self) -> Optional[ResourceInstance]:
@@ -720,22 +713,6 @@ class Resource:
     def _kube_v1_api(self) -> kubernetes.client.CoreV1Api:
         return kubernetes.client.CoreV1Api(api_client=self.client.client)
 
-    def client_wait_deleted(self, timeout: int) -> bool:
-        """
-        client-side Wait until resource is deleted
-
-        Args:
-            timeout (int): Time to wait for the resource.
-
-        Raises:
-            TimeoutExpiredError: If resource still exists.
-        """
-        samples = TimeoutSampler(wait_timeout=timeout, sleep=1, func=lambda: self.exists)
-        for sample in samples:
-            if not sample:
-                return True
-        return False
-
     def wait_for_status(
         self, status: str, timeout: int = TIMEOUT_4MINUTES, stop_status: str | None = None, sleep: int = 1
     ) -> None:
@@ -795,9 +772,6 @@ class Resource:
 
         Returns:
             bool: True if create succeeded, False otherwise.
-
-        Raises:
-            ValueMismatch: When body value doesn't match class value
         """
         if not self.res:
             self.to_dict()
@@ -826,12 +800,12 @@ class Resource:
                 hashed_data = self.hash_resource_dict(resource_dict=self.instance.to_dict())
                 self.logger.info(f"Deleting {hashed_data}")
                 self.logger.debug(f"\n{yaml.dump(hashed_data)}")
-
                 self.api.delete(name=self.name, namespace=self.namespace, body=body)
+
                 if wait:
                     return self.wait_deleted(timeout=timeout)
-                return True
 
+                return True
             except (NotFoundError, TimeoutExpiredError):
                 return False
 
@@ -879,16 +853,12 @@ class Resource:
 
     @staticmethod
     def retry_cluster_exceptions(
-        func,
-        exceptions_dict: Dict[type[Exception], List[str]] = DEFAULT_CLUSTER_RETRY_EXCEPTIONS,
-        timeout: int = TIMEOUT_10SEC,
-        sleep_time: int = 1,
-        **kwargs: Any,
+        func, exceptions_dict: Dict[type[Exception], List[str]] = DEFAULT_CLUSTER_RETRY_EXCEPTIONS, **kwargs: Any
     ) -> Any:
         try:
             sampler = TimeoutSampler(
-                wait_timeout=timeout,
-                sleep=sleep_time,
+                wait_timeout=TIMEOUT_10SEC,
+                sleep=1,
                 func=func,
                 print_log=False,
                 exceptions_dict=exceptions_dict,
@@ -1028,9 +998,7 @@ class Resource:
                     if cond["type"] == condition and cond["status"] == status:
                         return
 
-    def api_request(
-        self, method: str, action: str, url: str, retry_params: dict[str, int] | None = None, **params: Any
-    ) -> dict[str, Any]:
+    def api_request(self, method: str, action: str, url: str, **params: Any) -> Dict[str, Any]:
         """
         Handle API requests to resource.
 
@@ -1038,32 +1006,19 @@ class Resource:
             method (str): Request method (GET/PUT etc.).
             action (str): Action to perform (stop/start/guestosinfo etc.).
             url (str): URL of resource.
-            retry_params (dict): dict of timeout and sleep_time values for retrying the api request call
 
         Returns:
            data(dict): response data
 
         """
         client: DynamicClient = self.privileged_client or self.client
+        response = client.client.request(
+            method=method,
+            url=f"{url}/{action}",
+            headers=client.client.configuration.api_key,
+            **params,
+        )
 
-        api_request_params = {
-            "url": f"{url}/{action}",
-            "method": method,
-            "headers": client.client.configuration.api_key,
-        }
-        if retry_params:
-            response = self.retry_cluster_exceptions(
-                func=client.client.request,
-                timeout=retry_params.get("timeout", TIMEOUT_10SEC),
-                sleep_time=retry_params.get("sleep_time", TIMEOUT_1SEC),
-                **api_request_params,
-                **params,
-            )
-        else:
-            response = client.client.request(
-                **api_request_params,
-                **params,
-            )
         try:
             return json.loads(response.data)
         except json.decoder.JSONDecodeError:
@@ -1072,7 +1027,7 @@ class Resource:
     def wait_for_conditions(self) -> None:
         timeout_watcher = TimeoutWatch(timeout=30)
         for sample in TimeoutSampler(
-            wait_timeout=TIMEOUT_30SEC,
+            wait_timeout=30,
             sleep=1,
             func=lambda: self.exists,
         ):
@@ -1561,6 +1516,4 @@ class ResourceEditor:
             patches=patches,
             action_text=action_text,
             action=action,
-            timeout=TIMEOUT_30SEC,
-            sleep_time=TIMEOUT_5SEC,
         )
